/**
 * The type used for returning account balance information.
 * @remark All provided amounts are in weis.
 */
export type Balance = {
    availableOnC: bigint;
    availableOnP: bigint;
    wrappedOnC: bigint;
    stakedOnP: bigint;
    notImportedToC: bigint;
    notImportedToP: bigint;
};
/**
 * FTSO reward claim types
 */
export declare enum ClaimType {
    DIRECT = 0,
    FEE = 1,
    WNAT = 2,
    MIRROR = 3,
    CCHAIN = 4
}
/**
 * The type used for returning FTSO reward state information
 */
export type FtsoRewardState = {
    rewardEpochId: bigint;
    beneficiary: string;
    amount: bigint;
    claimType: ClaimType;
    initialised: boolean;
};
/**
 * The type used for specifying FTSO reward claims
 */
export type FtsoRewardClaim = {
    rewardEpochId: bigint;
    beneficiary: string;
    amount: bigint;
    claimType: ClaimType;
};
/**
 * The type used for specifying FTSO reward claims with Merkle proofs
 */
export type FtsoRewardClaimWithProof = {
    merkleProof: string[];
    body: FtsoRewardClaim;
};
/**
 * The type used for returning FTSO delegate information
 */
export type FtsoDelegate = {
    address: string;
    shareBP: bigint;
};
/**
 * The type used for returning information on stakes on the P-chain
 */
export type Stake = {
    txId: string;
    type: string;
    pAddress: string;
    nodeId: string;
    startTime: bigint;
    endTime: bigint;
    amount: bigint;
    feePercentage?: number;
};
//# sourceMappingURL=iotype.d.ts.map