import { EIP1193Wallet } from "./wallet";
import { EIP1193Based } from "./core";
import { EIP1193Provider } from "./provider";
export type OnWalletChange = (wallet: EIP1193Wallet) => void;
/**
 * The class that controls SDK-compatible wallets representing EIP-1193 accounts.
 */
export declare class EIP1193WalletController extends EIP1193Based {
    /**
     * The constructor of the controller.
     * @param provider Provider object of class {@link EIP1193Provider}.
     */
    constructor(provider: EIP1193Provider);
    protected _onWalletChange: OnWalletChange | null;
    protected _wallets: {
        [id: string]: EIP1193Wallet;
    };
    /**
     * Returns SDK-compatible wallets for all available accounts.
     * @returns An array of objects of class {@link EIP1193Wallet}.
     */
    getWallets(): Promise<Array<EIP1193Wallet>>;
    /**
     * Returns the SDK-compatible wallet corresponding to the currently active account.
     * @returns Returns an object of class {@link EIP1193Wallet} or null.
     */
    getActiveWallet(): Promise<EIP1193Wallet | null>;
    /**
     * Registers a listener that is called whenever the active account is changed.
     * @param listener A void function that receives an object of class {@link EIP1193Wallet} as input.
     * @remark The object received by `listener` is the wallet corresponding to the new active account.
     * @remark If `listener` is null, the previous listener is unregistered.
     */
    onWalletChange(listener: OnWalletChange | null): void;
    protected _getWallet(account: string): EIP1193Wallet;
    protected _updateWallets(addresses: Array<string>): void;
}
//# sourceMappingURL=controller.d.ts.map