import { Wallet } from "../";
import { EIP1193Based, EIP1193Core } from "./core";
/**
 * The class that implements {@link Wallet} and represents an EIP-1193 account.
 */
export declare class EIP1193Wallet extends EIP1193Based implements Wallet {
    constructor(core: EIP1193Core, address: string);
    protected _address: string;
    protected _publicKey: string;
    /**
     * Returns the C-chain address of the wallet.
     * @returns The C-chain address in the hexadecimal encoding.
     */
    getCAddress(): Promise<string>;
    /**
     * Returns the public key of the wallet.
     * @returns The public key in the hexadecimal encoding.
     * @remark When called for the first time, the function requests a message signature,
     * from which the public key is recovered.
     */
    getPublicKey(): Promise<string>;
    /**
     * Signs a message with ETH prefix.
     * @param message UTF8 encoded message.
     * @returns The signature in hexadecimal encoding.
     */
    signEthMessage(message: string): Promise<string>;
    /**
     * Signs and submits a C-chain (Ethereum Virtual Machine) transaction.
     * @param tx Unsigned C-chain (EVM) transaction in hexadecimal encoding.
     * @returns The transaction id in hexadecimal encoding.
     */
    signAndSubmitCTransaction(tx: string): Promise<string>;
    protected _recoverPublicKey(msg: string, signature: string, address: string): string;
    protected _hexUtf8(utf8String: string): string;
    protected _valueToHex(value: number | bigint | null): string;
}
//# sourceMappingURL=wallet.d.ts.map