import { FlrApp, EthApp } from "./signer";
import { LedgerWallet } from "./wallet";
import { LedgerCore } from "./core";
/**
 * The class that controls SDK-compatible wallets representing Ledger accounts.
 */
export declare class LedgerWalletController {
    /**
     * The constructor of the controller.
     * @param flrApp Object of class {@link FlrApp}.
     * @param ethApp Object of class {@link EthApp}.
     * @remark At least one of the input parameters must be different than null.
     */
    constructor(flrApp?: FlrApp, ethApp?: EthApp);
    static readonly FLR_APP = "Flare Network";
    static readonly ETH_APP = "Ethereum";
    protected readonly _core: LedgerCore;
    protected readonly _flrApp: FlrApp;
    protected readonly _ethApp: EthApp;
    protected _wallets: {
        [path: string]: {
            [signer: string]: LedgerWallet | null;
        };
    };
    /**
     * Returns the SDK-compatible wallet corresponding to the account
     * determined by the given derivation path.
     * @param bip44Path The string representing a BIP-44 derivation path.
     * @param app The string specifying the app the wallet should be compatible with (optional).
     * @returns An object of class {@link LedgerWallet}.
     */
    getWallet(bip44Path: string, app?: string): Promise<LedgerWallet>;
    /**
     * Returns the currently active app on the connected Ledger device.
     * @returns A string representing the app name.
     */
    getActiveApp(): Promise<string>;
    protected _setupWallets(path: string): void;
}
//# sourceMappingURL=controller.d.ts.map