import { Wallet } from "../";
import { TrezorConnector } from "./connector";
/**
 * The class that implements {@link Wallet} and represents a Trezor account.
 */
export declare class TrezorWallet implements Wallet {
    constructor(connector: TrezorConnector, bip44Path: string);
    protected readonly _connector: TrezorConnector;
    protected readonly _path: string;
    protected _address: string;
    protected _publicKey: string;
    /**
     * Returns the public key of the wallet.
     * @returns The public key in the hexadecimal encoding.
     */
    getPublicKey(): Promise<string>;
    /**
     * Returns the C-chain address of the wallet.
     * @returns The C-chain address in the hexadecimal encoding.
     */
    getCAddress(): Promise<string>;
    /**
     * Signs a message with ETH prefix.
     * @param message UTF8 encoded message.
     * @returns The signature in hexadecimal encoding.
     */
    signEthMessage(message: string): Promise<string>;
    /**
     * Signs a C-chain (Ethereum Virtual Machine) transaction.
     * @param tx Unsigned C-chain (EVM) transaction in hexadecimal encoding.
     * @returns The signature in hexadecimal encoding.
     */
    signCTransaction(tx: string): Promise<string>;
    protected _readResponse(response: any, method: string): any;
    protected _prefixedHex(hex: string): string;
    protected _valueToHex(value: number | bigint | null): string | null;
}
//# sourceMappingURL=wallet.d.ts.map